/*
 * sapphire.hh - Header which includes all the headers we need.
 * Copyright (C) 2000 Frank Hale
 * frankhale@lycos.com
 * http://sapphire.sourceforge.net/
 *
 * Updated: 6 Nov 2000
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef _SAPPHIRE_HH_
#define _SAPPHIRE_HH_

#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <stdarg.h>
#include <sys/stat.h>
#include <sys/types.h>

#include <X11/Xlib.h>
#include <X11/Xos.h>
#include <X11/Xutil.h>
#include <X11/Xproto.h>
#include <X11/keysym.h>
#include <X11/Xatom.h>
#include <X11/cursorfont.h>
#include <X11/Xresource.h>
#include <X11/extensions/shape.h>

static char* windowmanager_author 	= "Frank Hale";
static char* windowmanager_author_email = "frankhale@yahoo.com";
static char* windowmanager_name 	= "sapphire";
static char* windowmanager_version 	= "Sapphire 0.15.6 (Blackberry)";
static char* windowmanager_usage 	= "[-display <display>] [-version]\n";
static char* windowmanager_exit_message = "\nThank you for using Sapphire.\n\nPlease Send all bug reports, suggestions, ideas, patches to frankhale@yahoo.com\n";

// Don't change this please!!! At least not yet! Bad things will happen!!!!
static char* configuration_home		= "/usr/local/share/sapphire";

static char* HOME = getenv("HOME");

typedef enum {
	Window_Here       = 1<<1,
	Window_Away       = 1<<2,
	Window_Shaded     = 1<<3,
	Window_Icon       = 1<<4,
	Window_ShadedAway = 1<<5
} WindowState;

/* default settings */
#define DEFAULT_FOREGROUND_COLOR 	"black"
#define DEFAULT_BACKGROUND_COLOR	"lightgray"
#define DEFAULT_BORDER_COLOR		"black"
#define DEFAULT_BORDER_SIZE		1
#define DEFAULT_SPACE			3
#define DEFAULT_MARGIN			6
#define DEFAULT_MINIMUM_SIZE		10

// MOTIF hints
#define MwmHintsFunctions     		(1l << 0)
#define MwmHintsDecorations   		(1l << 1)

#define MwmFuncAll            		(1l << 0)
#define MwmFuncResize         		(1l << 1)
#define MwmFuncMove           		(1l << 2)
#define MwmFuncIconify        		(1l << 3)
#define MwmFuncMaximize       		(1l << 4)
#define MwmFuncClose          		(1l << 5)

#define MwmDecorAll           		(1l << 0)
#define MwmDecorBorder        		(1l << 1)
#define MwmDecorHandle        		(1l << 2)
#define MwmDecorTitle         		(1l << 3)
#define MwmDecorMenu          		(1l << 4)
#define MwmDecorIconify       		(1l << 5)
#define MwmDecorMaximize      		(1l << 6)

#define PropMwmHintsElements 	 	3

// this structure only contains 3 elements... the Motif 2.0 structure contains
// 5... we only need the first 3... so that is all we will define
typedef struct MwmHints {
  unsigned long flags, functions, decorations;
} MwmHints;

struct Widget {
	Window window;
	int x,y;
	int width,height;
	bool pressed;
};

extern int handle_xerror(Display *dpy, XErrorEvent *e);
extern void err(char *fmt, ...);
extern void show_event(XEvent e);
extern void signalhandler(int i);

// Forward declarations for all the classes in Sapphire
class BImageControl;
class BImage;
class WindowManager;
class Client;
class BaseMenuItem;
class WindowMenuItem; // in windowmenu.{hh,cc}
class BaseMenu;
class RootMenu;
class IconMenu;
class Toolbar;
class Theme;
class Scanner;
class MenuLex;
class WindowMenu;
class FancyMenu;      // in basemenu.{hh,cc}

// Include all of the header files
#include "linkedlist.hh"
#include "image.hh"
#include "theme.hh"
#include "basemenuitem.hh"
#include "basemenu.hh"
#include "client.hh"
#include "windowmanager.hh"
#include "toolbar.hh"
#include "rootmenu.hh"
#include "iconmenu.hh"
#include "scanner.hh"
#include "menulex.hh"
#include "windowmenu.hh"

#endif
