/*
 * windowmenu.cc - Implements a menu used to tell what desktop a window is on.
 * Copyright (C) 2000 Frank Hale, Felipe Bergo
 * frankhale@lycos.com
 * http://sapphire.sourceforge.net/
 *
 * Updated: 5 Nov 2000
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "sapphire.hh"

WindowMenu::WindowMenu() :
	FancyMenu()
{
	setMenuTitle("Windows");
	update_all();
	wm->addToExtraMenuList(this);
}


WindowMenu::~WindowMenu(void)
{
}

void WindowMenu::insert(char *name, Client *c, WindowState _state)
{
	WindowMenuItem *item = new WindowMenuItem();
			
	if(name==NULL) {
		char *noname = "no name";
		name = noname;
	}
	
	item->name = new char[strlen(name)+1];	
	item->wstate=_state;
	strcpy(item->name, name);
	
	item->client = c;
	
	// defaults
	item->icon = None;
	item->sub  = None;
	item->isSelected=False;
	item->exec = "";
	item->function = 0;
	item->item_x = item->item_y = 0;

	getMenuItemList()->insert(item);
}

void WindowMenu::addWindow(char *name, Client *c, WindowState _state)
{
	insert(name, c, _state);
	update_all();
}

void WindowMenu::removeWindow(Client *c) 
{
	

	LinkedList<BaseMenuItem> *items;       
	items=getMenuItemList();
	LinkedListIterator<BaseMenuItem> lli(items);

	for(; lli.current(); lli++)
		if (lli.current()->client == c ) 
		{
			items->remove(lli.current());
			update_all();
			return;
		}
	
}

void WindowMenu::update_states() {
	LinkedList<BaseMenuItem> *items;       
	items=getMenuItemList();
	LinkedListIterator<BaseMenuItem> lli(items);
	WindowMenuItem *wmi;
	int mask,desk;

	for(; lli.current(); lli++) {
		wmi=(WindowMenuItem *)(lli.current());
		wmi->wstate=wmi->client->getWindowState();
		mask=wmi->client->getDesktopMask();
		if (mask==0xffff)
			wmi->desktop=-1;
		else {
			for(desk=0;mask!=1;mask>>=1) desk++;
			wmi->desktop=desk;
		}
	}
}

// if I wanted all sub menus to have the same button behavior I would declare
// a class derived from BaseMenu which would only define the button functions
// and then derive the main menu and sub menus from that so all menus would
// have the same behavior when the items were clicked.
//
// With the code the way it is now only the first main menu will have the button
// behavior defined by these functions.
void WindowMenu::handle_button1_press(BaseMenuItem *curr)
{
	WindowMenuItem *item;
	int mask,desk;
	
	if (curr)
	{
		item = (WindowMenuItem *) curr;
		item->wstate=item->client->getWindowState();

		switch(item->wstate) {
		case Window_Icon:
			item->client->unhide(item->client);
			item->client->raise();
			break;
		case Window_Here:
			item->client->raise();
			break;
		case Window_Away:
			mask=item->client->getDesktopMask();
			for (desk=0; mask!=1; mask>>=1)
				++desk;
			wm->goToDesktop(desk);
			item->client->raise();
			break;
		case Window_Shaded:
			item->client->unshade();
			item->client->raise();
			break;
		case Window_ShadedAway:
			mask=item->client->getDesktopMask();
			for (desk=0; mask!=1; mask>>=1)
				++desk;
			wm->goToDesktop(desk);
			item->client->unshade();
			item->client->raise();
			break;
		}
		hide(this);
	}
}

void WindowMenu::handle_button2_press(BaseMenuItem* curr) {
	this->handle_button3_press(curr);
}

void WindowMenu::handle_button3_press(BaseMenuItem* curr) {
	WindowMenuItem *item;
	int mask,desk;
	
	if (curr)
	{
		item = (WindowMenuItem *) curr;
		item->wstate=item->client->getWindowState();

		switch(item->wstate) {
		case Window_Icon:
			item->client->unhide(item->client);
			item->client->raise();
			break;
		case Window_Here:
			item->client->raise();
			break;
		case Window_Away:
			item->client->setDesktopMask(wm->getCurrentDesktopMask());
			item->client->updateVisibility(wm->getCurrentDesktopMask());
			item->client->raise();
			break;
		case Window_Shaded:
			item->client->unshade();
			item->client->raise();
			break;
		case Window_ShadedAway:
			item->client->setDesktopMask(wm->getCurrentDesktopMask());
			item->client->updateVisibility(wm->getCurrentDesktopMask());
			item->client->unshade();
			item->client->raise();
			break;
		}
		hide(this);
	}
}

void WindowMenu::handle_button1_release(BaseMenuItem *curr)
{
}

void WindowMenu::setAllMenuTitlesVisible(BaseMenu *sub, bool s) {
	if (s) update_states();
	BaseMenu::setAllMenuTitlesVisible(sub,s);
}
